@@ -49,10 +49,10 @@ $actions{graph} = sub {
     $cnt_deny = $cnt_halfopen = $cnt_permit = "?";
   }
   # make pictures
-  foreach ("1h", "1d", "1w", "1m", "1y") {
-    my $fn = "$config{picpath}/graylist$_.png";
-    RRDs::graph($fn, "-s", "end-$_", "-l", "0", "-w", "500",
-                "-t", "Graylisting per $_",
+  foreach my $period("1h", "1d", "1w", "1m", "1y") {
+    my $fn = $config{picpath} . "/graylist" . $period . ".png";
+    RRDs::graph($fn, "-s", "end-" . $period, "-l", "0", "-w", "500",
+                "-t", "Graylisting per " . $period,
                 "DEF:deny=$config{rrdfile}:deny:MAX",
                 "DEF:halfopen=$config{rrdfile}:halfopen:MAX",
                 "DEF:permit=$config{rrdfile}:permit:MAX",
@@ -84,10 +84,10 @@ $actions{graph} = sub {
     die "update $config{rrdfile2} failed: $err" if $err;
   }
   # make pictures
-  foreach ("1h", "1d", "1w", "1m", "1y") {
-    my $fn = "$config{picpath}/mailcount$_.png";
-    RRDs::graph($fn, "-s", "end-$_", "-l", "0", "-w", "500",
-                "-t", "Mails per $_",
+  foreach my $period("1h", "1d", "1w", "1m", "1y") {
+    my $fn = $config{picpath} . "/mailcount" . $period . ".png";
+    RRDs::graph($fn, "-s", "end-" . $period, "-l", "0", "-w", "500",
+                "-t", "Mails per " . $period,
                 "DEF:minmails=$config{rrdfile2}:mails:MIN",
                 "DEF:avgmails=$config{rrdfile2}:mails:AVERAGE",
                 "DEF:maxmails=$config{rrdfile2}:mails:MAX",
