@@ -23,6 +23,9 @@ $DEFAULTS{"db_field_ts_entry"}	= "ts_entry";
 $DEFAULTS{"db_field_ts_latest"}	= "ts_latest";
 $DEFAULTS{"db_field_ts_ok"}	= "ts_ok";
 $DEFAULTS{"db_field_count"}	= "count";
+$DEFAULTS{"db_field_size"}	= "size";
+$DEFAULTS{"db_field_queue_id"}	= "queue_id";
+$DEFAULTS{"db_field_instance"}	= "instance";
 $DEFAULTS{"db_key_err"}		= "duplicate key violates unique constraint";
 $DEFAULTS{"listen"}		= "/var/run/graypold.sock";
 $DEFAULTS{"owner"}		= "postfix";
@@ -61,12 +64,7 @@ sub load_config ()
     next unless /^([^\s]+)\s+=\s+(.+)$/;
     my $key = $1;
     my $value = $2;
-    foreach (keys %DEFAULTS) {
-      if ($key eq $_) {
-        $config{$_} = $value;
-        last;
-      }
-    }
+    $config{$key} = $value if exists $DEFAULTS{$key};
   }
   close(FH);
   return "";
